shellcheckr: Run 'shellcheck' on a document

Description Usage Arguments Value

View source: R/shellcheckr.R

Description

Runs shellcheck on a document and returns the JSON output.

Usage

1

Arguments

path

path of file to check. The active document is used if this is missing.

Value

JSON output of shellcheck.


sambrightman/shellcheckr documentation built on Sept. 3, 2020, 12:03 a.m.