shellcheckrMarkers: Run 'shellcheck' on a document and parse to markers

Description Usage Arguments Details

View source: R/shellcheckr.R

Description

Runs shellcheck and parses output into markers with ShellCheck wiki links for the problematic codes.

Usage

1

Arguments

path

path of file to check. The active document is used if this is missing.

Details

Intended for use as an RStudio Addin.


sambrightman/shellcheckr documentation built on Sept. 3, 2020, 12:03 a.m.