Description Usage Arguments Value
Runs shellcheck on a document and returns the JSON output.
1 | shellcheckr(path)
|
path |
path of file to check. The active document is used if this is missing. |
JSON output of shellcheck.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.